==> mingw-w64-clang-aarch64-kxmlgui-qt5-5.111.0-1-any.pkg.tar.zst: clangarm64/include/KF5/KXmlGui/kxmlgui_export.h <==

#ifndef KXMLGUI_EXPORT_H
#define KXMLGUI_EXPORT_H

#ifdef KXMLGUI_STATIC_DEFINE
#  define KXMLGUI_EXPORT
#  define KXMLGUI_NO_EXPORT
#else
#  ifndef KXMLGUI_EXPORT
#    ifdef KF5XmlGui_EXPORTS
        /* We are building this library */
#      define KXMLGUI_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KXMLGUI_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KXMLGUI_NO_EXPORT
#    define KXMLGUI_NO_EXPORT 
#  endif
#endif

#ifndef KXMLGUI_DECL_DEPRECATED
#  define KXMLGUI_DECL_DEPRECATED __declspec(deprecated)
#endif

#ifndef KXMLGUI_DECL_DEPRECATED_EXPORT
#  define KXMLGUI_DECL_DEPRECATED_EXPORT KXMLGUI_EXPORT KXMLGUI_DECL_DEPRECATED
#endif

#ifndef KXMLGUI_DECL_DEPRECATED_NO_EXPORT
#  define KXMLGUI_DECL_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT KXMLGUI_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KXMLGUI_NO_DEPRECATED
#    define KXMLGUI_NO_DEPRECATED
#  endif
#endif

#define KXMLGUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KXMLGUI_NO_DEPRECATED) && !defined(KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KXMLGUI_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KXMLGUI_NO_DEPRECATED_WARNINGS) && !defined(KXMLGUI_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KXMLGUI_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KXMLGUI_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KXMLGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KXMLGUI_NO_DEPRECATED)
#  undef KXMLGUI_DEPRECATED
#  define KXMLGUI_DEPRECATED_EXPORT KXMLGUI_EXPORT
#  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT
#elif defined(KXMLGUI_NO_DEPRECATED_WARNINGS)
#  define KXMLGUI_DEPRECATED
#  define KXMLGUI_DEPRECATED_EXPORT KXMLGUI_EXPORT
#  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT
#else
#  define KXMLGUI_DEPRECATED KXMLGUI_DECL_DEPRECATED
#  define KXMLGUI_DEPRECATED_EXPORT KXMLGUI_DECL_DEPRECATED_EXPORT
#  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KXMLGUI_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KXMLGUI_NO_DEPRECATED
#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
#endif
#ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
#  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KXMLGUI_DEPRECATED_WARNINGS_SINCE
#  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x56f00
#  endif
#endif

#ifndef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KXMLGUI_DEPRECATED
#  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KXMLGUI_DEPRECATED_VERSION_4_0(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_4_0(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x40100
#  define KXMLGUI_DEPRECATED_VERSION_4_1(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_4_1(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KXMLGUI_DEPRECATED_VERSION_5_0(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_0(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x54b00
#  define KXMLGUI_DEPRECATED_VERSION_5_75(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_75(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x55300
#  define KXMLGUI_DEPRECATED_VERSION_5_83(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_83(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x55400
#  define KXMLGUI_DEPRECATED_VERSION_5_84(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_84(text)
#endif
#define KXMLGUI_DEPRECATED_VERSION_4(minor, text)      KXMLGUI_DEPRECATED_VERSION_4_##minor(text)
#define KXMLGUI_DEPRECATED_VERSION_5(minor, text)      KXMLGUI_DEPRECATED_VERSION_5_##minor(text)
#define KXMLGUI_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION(major, minor, text)
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KXMLGUI_EXPORT_H */

==> mingw-w64-clang-aarch64-kxmlgui-qt5-5.113.0-1-any.pkg.tar.zst: clangarm64/include/KF5/KXmlGui/kxmlgui_export.h <==

#ifndef KXMLGUI_EXPORT_H
#define KXMLGUI_EXPORT_H

#ifdef KXMLGUI_STATIC_DEFINE
#  define KXMLGUI_EXPORT
#  define KXMLGUI_NO_EXPORT
#else
#  ifndef KXMLGUI_EXPORT
#    ifdef KF5XmlGui_EXPORTS
        /* We are building this library */
#      define KXMLGUI_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KXMLGUI_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KXMLGUI_NO_EXPORT
#    define KXMLGUI_NO_EXPORT 
#  endif
#endif

#ifndef KXMLGUI_DECL_DEPRECATED
#  define KXMLGUI_DECL_DEPRECATED __declspec(deprecated)
#endif

#ifndef KXMLGUI_DECL_DEPRECATED_EXPORT
#  define KXMLGUI_DECL_DEPRECATED_EXPORT KXMLGUI_EXPORT KXMLGUI_DECL_DEPRECATED
#endif

#ifndef KXMLGUI_DECL_DEPRECATED_NO_EXPORT
#  define KXMLGUI_DECL_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT KXMLGUI_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KXMLGUI_NO_DEPRECATED
#    define KXMLGUI_NO_DEPRECATED
#  endif
#endif

#define KXMLGUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KXMLGUI_NO_DEPRECATED) && !defined(KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KXMLGUI_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KXMLGUI_NO_DEPRECATED_WARNINGS) && !defined(KXMLGUI_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KXMLGUI_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KXMLGUI_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KXMLGUI_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KXMLGUI_NO_DEPRECATED)
#  undef KXMLGUI_DEPRECATED
#  define KXMLGUI_DEPRECATED_EXPORT KXMLGUI_EXPORT
#  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT
#elif defined(KXMLGUI_NO_DEPRECATED_WARNINGS)
#  define KXMLGUI_DEPRECATED
#  define KXMLGUI_DEPRECATED_EXPORT KXMLGUI_EXPORT
#  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT
#else
#  define KXMLGUI_DEPRECATED KXMLGUI_DECL_DEPRECATED
#  define KXMLGUI_DEPRECATED_EXPORT KXMLGUI_DECL_DEPRECATED_EXPORT
#  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KXMLGUI_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KXMLGUI_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KXMLGUI_NO_DEPRECATED
#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
#endif
#ifdef KXMLGUI_NO_DEPRECATED_WARNINGS
#  define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KXMLGUI_DEPRECATED_WARNINGS_SINCE
#  ifdef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KXMLGUI_DEPRECATED_WARNINGS_SINCE 0x57100
#  endif
#endif

#ifndef KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KXMLGUI_DEPRECATED
#  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KXMLGUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KXMLGUI_DEPRECATED_VERSION_4_0(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_4_0(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x40100
#  define KXMLGUI_DEPRECATED_VERSION_4_1(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_4_1(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KXMLGUI_DEPRECATED_VERSION_5_0(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_0(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x54b00
#  define KXMLGUI_DEPRECATED_VERSION_5_75(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_75(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x55300
#  define KXMLGUI_DEPRECATED_VERSION_5_83(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_83(text)
#endif

#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x55400
#  define KXMLGUI_DEPRECATED_VERSION_5_84(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
#else
#  define KXMLGUI_DEPRECATED_VERSION_5_84(text)
#endif
#define KXMLGUI_DEPRECATED_VERSION_4(minor, text)      KXMLGUI_DEPRECATED_VERSION_4_##minor(text)
#define KXMLGUI_DEPRECATED_VERSION_5(minor, text)      KXMLGUI_DEPRECATED_VERSION_5_##minor(text)
#define KXMLGUI_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION(major, minor, text)
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KXMLGUI_EXPORT_H */
